<?php
namespace Clonable\Translator\Controller\Adminhtml\Product;

use Exception;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Catalog\Model\ResourceModel\Product\Collection;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\MessageQueue\PublisherInterface;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Catalog\Model\ResourceModel\Product\CollectionFactory;
use Clonable\Translator\Model\Logger\Logger;
use Clonable\Translator\Model\ConfigManager;
use Magento\Catalog\Api\ProductRepositoryInterface;

class MassTranslate extends Action
{
    private PublisherInterface $publisher;
    protected Filter $filter;
    protected CollectionFactory $collectionFactory;
    private Logger $logger;
    private ConfigManager $configManager;

    private ProductRepositoryInterface $productRepository;

    public function __construct(
        Context $context,
        Filter $filter,
        CollectionFactory $collectionFactory,
        PublisherInterface $publisher,
        logger $logger,
        ConfigManager $configManager,
        ProductRepositoryInterface $productRepository
    ){
        parent::__construct($context);
        $this->filter = $filter;
        $this->collectionFactory = $collectionFactory;
        $this->publisher = $publisher;
        $this->logger = $logger;
        $this->configManager = $configManager;
        $this->productRepository = $productRepository;
    }

    /**
     *
     * @throws LocalizedException
     */
    public function execute()
    {
        if (!$this->configManager->isEnabled(0)) {
            $this->messageManager->addErrorMessage(
                __('Clonable Translator is disabled. Please enable it in the configuration.')
            );
            return $this->_redirect($this->_redirect->getRefererUrl());
        }
        $collection = $this->filter->getCollection($this->collectionFactory->create());
        $productCount = $this->processCollection($collection);

        $this->messageManager->addSuccessMessage(
            __('A total of %1 product(s) have been added to the queue for translation.', $productCount)
        );
        return $this->_redirect($this->_redirect->getRefererUrl());
    }

    /**
     * @param $collection
     * @return int
     */
    private function processCollection($collection): int
    {
        $productCount = 0;

        foreach ($collection as $product) {
            try {
                $storeIds = $product->getStoreIds();
                foreach ($storeIds as $storeId) {
                    $product = $this->productRepository->get($product->getSku(), false, $storeId, true);
                    if ($this->configManager->isTranslatable($product)) {
                        continue;
                    }
                    $this->publisher->publish($this->configManager->getTopicQueueForProduct(), $product->getSku());
                    $productCount++;
                    break;
                }
            } catch (Exception $e) {
                $this->logger->error(
                    __('Error adding product ID %1 to the queue: %2', $product->getId(), $e->getMessage())
                );
                $this->messageManager->addErrorMessage(
                    __('Error adding product ID %1 to the queue: %2', $product->getId(), $e->getMessage())
                );
            }
        }

        return $productCount;
    }
}

