<?php

namespace Clonable\Translator\Model\Js;

use Clonable\Translator\Model\ConfigManager;
use Magento\Framework\Exception\LocalizedException;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Translation\Model\Js\Config;

class DataProvider extends \Magento\Translation\Model\Js\DataProvider {

    protected StoreManagerInterface $storeManager;
    protected ConfigManager $configManager;

    public function __construct(\Magento\Framework\App\State $appState,
                                Config $config,
                                \Magento\Framework\Filesystem\File\ReadFactory $fileReadFactory,
                                \Magento\Framework\Phrase\RendererInterface $translate,
                                \Magento\Framework\Component\ComponentRegistrar $componentRegistrar,
                                \Magento\Framework\Component\DirSearch $dirSearch,
                                \Magento\Framework\View\Design\Theme\ThemePackageList $themePackageList,
                                StoreManagerInterface $storeManager,
                                ConfigManager $configManager,
                                \Magento\Framework\App\Utility\Files $filesUtility = null) {
        parent::__construct($appState, $config, $fileReadFactory, $translate, $componentRegistrar, $dirSearch, $themePackageList, $filesUtility);
        $this->storeManager = $storeManager;
        $this->configManager = $configManager;
    }


    public function getData($themePath) {
        /**
         * This code is almost the same as the original, with the only difference being that we fill the dictionary with the original strings,
         * so that they can be translated by Clonable. We only do this for stores with the option enabled, otherwise we call the original
         * function.
         */
        $requestedLocale = $this->getRequestedLocale();
        $currentStore = $this->getStoreForLocale($requestedLocale);

        if ($currentStore != null && $this->configManager->isEnabledOverrideTranslationDictionary($currentStore)) {
            $areaCode = $this->appState->getAreaCode();

            $files = array_merge(
                $this->filesUtility->getJsFiles('base', $themePath),
                $this->filesUtility->getJsFiles($areaCode, $themePath),
                $this->filesUtility->getStaticHtmlFiles('base', $themePath),
                $this->filesUtility->getStaticHtmlFiles($areaCode, $themePath)
            );

            $dictionary = [];
            $dictionary['.CLONABLE_TRANSLATIONS_JS_OVERRIDDEN'] = 'YES';  // This helps Clonable detect that the translations.json was overridden by the plugin

            foreach ($files as $filePath) {
                $read = $this->fileReadFactory->create($filePath[0], \Magento\Framework\Filesystem\DriverPool::FILE);
                $content = $read->readAll();
                foreach ($this->getPhrases($content) as $phrase) {
                    try {
                        $dictionary[$phrase] = $phrase;
                    } catch (\Exception $e) {
                        throw new LocalizedException(
                            __('Error while translating phrase "%s" in file %s.', $phrase, $filePath[0]),
                            $e
                        );
                    }
                }
            }

            ksort($dictionary);

            return $dictionary;
        } else {
            return parent::getData($themePath);
        }
    }

    private function getStoreForLocale($locale): ?int {
        if ($locale == null) {
            return null;
        }

        $allStores = $this->storeManager->getStores();
        foreach ($allStores as $store) {
            $storeLocale = $this->configManager->getLocale($store->getId());
            if ($storeLocale == $locale) {
                return $store->getId();
            }
        }

        return null;
    }

    private function getRequestedLocale(): ?string {
        $path = $_SERVER['REQUEST_URI'];
        // Check if the url is what we expect and ends with js-translation.json
        $len = strlen(Config::DICTIONARY_FILE_NAME);
        if (substr( $path, -$len ) === Config::DICTIONARY_FILE_NAME) {
            return substr($path, -($len+6), 5);
        } else {
            return null;
        }
    }
}
