<?php

namespace Clonable\Translator\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Catalog\Api\ProductRepositoryInterface;
use Clonable\Translator\Model\Product\Condition\ConditionChain;
use Clonable\Translator\Model\Service\Product\ProcessAssociatedProducts;

class ProductAfterSaveObserver implements ObserverInterface
{
    private ConditionChain $conditionChain;

    private ProcessAssociatedProducts $processAssociatedProducts;

    private ProductRepositoryInterface $productRepository;

    public function __construct
    (
        ConditionChain $conditionChain,
        ProcessAssociatedProducts $processAssociatedProducts,
        ProductRepositoryInterface $productRepository
    ){
        $this->conditionChain = $conditionChain;
        $this->processAssociatedProducts = $processAssociatedProducts;
        $this->productRepository = $productRepository;
    }

    public function execute(Observer $observer): void
    {
        $product = $observer->getEvent()->getProduct();
        if ($product->getStore()->isDefault()) {
            foreach ($product->getStoreIds() as $storeId) {
                $productByStore =$this->productRepository->get($product->getSku(), false, $storeId, true);
                if ($productByStore->getStore()->isDefault()) {
                    continue;
                }
                $this->conditionChain->process($productByStore);
                $this->processAssociatedProducts->processAssociatedProducts($productByStore);
            }
        }else {
            $this->conditionChain->process($product);
            $this->processAssociatedProducts->processAssociatedProducts($product);
        }
    }
}
