<?php

namespace Clonable\Translator\Plugin;

use Clonable\Translator\Model\Product\Condition\ConditionChain;
use Clonable\Translator\Model\Service\Product\ProcessAssociatedProducts;
use Magento\Catalog\Controller\Adminhtml\Product\Action\Attribute\Save;
use Magento\Catalog\Helper\Product\Edit\Action\Attribute;
use Magento\Framework\Controller\Result\Redirect;
use Magento\Catalog\Api\ProductRepositoryInterface;

class ProductAttributeSaveExecutePlugin
{
    /**
     * @var Attribute
     */
    protected Attribute $attributeHelper;

   private ConditionChain $conditionChain;

   private ProcessAssociatedProducts $processAssociatedProducts;

    private ProductRepositoryInterface $productRepository;

    public function __construct
    (
        Attribute $attributeHelper,
        ConditionChain $conditionChain,
        ProcessAssociatedProducts $processAssociatedProducts,
        ProductRepositoryInterface $productRepository

    ){
        $this->attributeHelper = $attributeHelper;
        $this->conditionChain = $conditionChain;
        $this->processAssociatedProducts = $processAssociatedProducts;
        $this->productRepository = $productRepository;
    }

    /**
     * @param Save $subject
     * @param Redirect $result
     * @return Redirect
     */
    public function afterExecute(Save $subject, Redirect $result): Redirect
    {
            $products = $this->attributeHelper->getProducts()->load()->getItems();
            foreach ($products as $product) {
                if ($product->getStore()->isDefault()) {
                    foreach ($product->getStoreIds() as $storeId) {
                        $productByStore =$this->productRepository->get($product->getSku(), false, $storeId, true);
                        if ($productByStore->getStore()->isDefault()) {
                            continue;
                        }
                        $this->conditionChain->process($productByStore);
                        $this->processAssociatedProducts->processAssociatedProducts($productByStore);
                    }
                }else {
                    $this->conditionChain->process($product);
                    $this->processAssociatedProducts->processAssociatedProducts($product);
                }
            }

        return $result;
    }
}
